@@ -25,7 +25,7 @@
  * Change the requested timestamp in the given inode.
  *
  * This was once shared with the kernel, but has diverged to the point
- * where its no longer worth the hassle of maintaining common code.
+ * where it's no longer worth the hassle of maintaining common code.
  */
 void
 libxfs_ichgtime(xfs_inode_t *ip, int flags)
@@ -40,10 +40,6 @@ libxfs_ichgtime(xfs_inode_t *ip, int flags)
 		ip->i_d.di_mtime.t_sec = (__int32_t)tv.tv_sec;
 		ip->i_d.di_mtime.t_nsec = (__int32_t)tv.tv_nsec;
 	}
-	if (flags & XFS_ICHGTIME_ACC) {
-		ip->i_d.di_atime.t_sec = (__int32_t)tv.tv_sec;
-		ip->i_d.di_atime.t_nsec = (__int32_t)tv.tv_nsec;
-	}
 	if (flags & XFS_ICHGTIME_CHG) {
 		ip->i_d.di_ctime.t_sec = (__int32_t)tv.tv_sec;
 		ip->i_d.di_ctime.t_nsec = (__int32_t)tv.tv_nsec;
@@ -57,6 +53,11 @@ libxfs_ichgtime(xfs_inode_t *ip, int flags)
  *
  * Initialize the inode's attributes and extent pointers if it
  * already has them (it will not if the inode has no links).
+ *
+ * NOTE: this has slightly different behaviour to the kernel in
+ * that this version requires the already allocated *ip being 
+ * passed in while the kernel version does the allocation and 
+ * returns it in **ip.
  */
 int
 libxfs_iread(
@@ -72,49 +73,109 @@ libxfs_iread(
 
 	ip->i_ino = ino;
 	ip->i_mount = mp;
-	if ((error = xfs_itobp(mp, tp, ip, &dip, &bp, bno)))
+
+	/*
+	 * Get pointer's to the on-disk inode and the buffer containing it.
+	 * If the inode number refers to a block outside the file system
+	 * then xfs_itobp() will return NULL.  In this case we should
+	 * return NULL as well.  Set i_blkno to 0 so that xfs_itobp() will
+	 * know that this is a new incore inode.
+	 */
+	error = xfs_itobp(mp, tp, ip, &dip, &bp, bno, 0, XFS_BUF_LOCK);
+	if (error) 
 		return error;
-	if (INT_GET(dip->di_core.di_magic, ARCH_CONVERT) != XFS_DINODE_MAGIC) {
+
+	/*
+	 * If we got something that isn't an inode it means someone
+	 * (nfs or dmi) has a stale handle.
+	 */
+	if (be16_to_cpu(dip->di_core.di_magic) != XFS_DINODE_MAGIC) {
 		xfs_trans_brelse(tp, bp);
 		return EINVAL;
 	}
+
+	/*
+	 * If the on-disk inode is already linked to a directory
+	 * entry, copy all of the inode into the in-core inode.
+	 * xfs_iformat() handles copying in the inode format
+	 * specific information.
+	 * Otherwise, just get the truly permanent information.
+	 */
 	if (dip->di_core.di_mode) {
-		xfs_xlate_dinode_core((xfs_caddr_t)&dip->di_core,
-					&(ip->i_d), 1);
-		if ((error = xfs_iformat(ip, dip))) {
+		xfs_dinode_from_disk(&ip->i_d, &dip->di_core);
+		error = xfs_iformat(ip, dip);
+		if (error)  {
 			xfs_trans_brelse(tp, bp);
 			return error;
 		}
 	} else {
-		ip->i_d.di_magic = INT_GET(dip->di_core.di_magic, ARCH_CONVERT);
-		ip->i_d.di_version = INT_GET(dip->di_core.di_version, ARCH_CONVERT);
-		ip->i_d.di_gen = INT_GET(dip->di_core.di_gen, ARCH_CONVERT);
-		ip->i_d.di_flushiter = INT_GET(dip->di_core.di_flushiter, ARCH_CONVERT);
+		ip->i_d.di_magic = be16_to_cpu(dip->di_core.di_magic);
+		ip->i_d.di_version = dip->di_core.di_version;
+		ip->i_d.di_gen = be32_to_cpu(dip->di_core.di_gen);
+		ip->i_d.di_flushiter = be16_to_cpu(dip->di_core.di_flushiter);
+		/*
+		 * Make sure to pull in the mode here as well in
+		 * case the inode is released without being used.
+		 * This ensures that xfs_inactive() will see that
+		 * the inode is already free and not try to mess
+		 * with the uninitialized part of it.
+		 */
 		ip->i_d.di_mode = 0;
+		/*
+		 * Initialize the per-fork minima and maxima for a new
+		 * inode here.  xfs_iformat will do it for old inodes.
+		 */
 		ip->i_df.if_ext_max =
 			XFS_IFORK_DSIZE(ip) / (uint)sizeof(xfs_bmbt_rec_t);
 	}
+
+	/*
+	 * The inode format changed when we moved the link count and
+	 * made it 32 bits long.  If this is an old format inode,
+	 * convert it in memory to look like a new one.  If it gets
+	 * flushed to disk we will convert back before flushing or
+	 * logging it.  We zero out the new projid_lo/hi field and the old link
+	 * count field.  We'll handle clearing the pad field (the remains
+	 * of the old uuid field) when we actually convert the inode to
+	 * the new format. We don't change the version number so that we
+	 * can distinguish this from a real new format inode.
+	 */
 	if (ip->i_d.di_version == XFS_DINODE_VERSION_1) {
 		ip->i_d.di_nlink = ip->i_d.di_onlink;
 		ip->i_d.di_onlink = 0;
-		ip->i_d.di_projid = 0;
+		xfs_set_projid(&ip->i_d, 0);
 	}
+
 	ip->i_delayed_blks = 0;
-	XFS_BUF_SET_REF(bp, XFS_INO_REF);
+	ip->i_size = ip->i_d.di_size;
+
+	/*
+	 * Use xfs_trans_brelse() to release the buffer containing the
+	 * on-disk inode, because it was acquired with xfs_trans_read_buf()
+	 * in xfs_itobp() above.  If tp is NULL, this is just a normal
+	 * brelse().  If we're within a transaction, then xfs_trans_brelse()
+	 * will only release the buffer if it is not dirty within the
+	 * transaction.  It will be OK to release the buffer in this case,
+	 * because inodes on disk are never destroyed and we will be
+	 * locking the new in-core inode before putting it in the hash
+	 * table where other processes can find it.  Thus we don't have
+	 * to worry about the inode being changed just because we released
+	 * the buffer.
+	 */
 	xfs_trans_brelse(tp, bp);
 	return 0;
 }
 
 /*
- * Allocate an inode on disk and return a copy of it's in-core version.
+ * Allocate an inode on disk and return a copy of its in-core version.
  * Set mode, nlink, and rdev appropriately within the inode.
  * The uid and gid for the inode are set according to the contents of
  * the given cred structure.
  *
  * This was once shared with the kernel, but has diverged to the point
- * where its no longer worth the hassle of maintaining common code.
+ * where it's no longer worth the hassle of maintaining common code.
  */
-static int
+int
 libxfs_ialloc(
 	xfs_trans_t	*tp,
 	xfs_inode_t	*pip,
@@ -158,7 +219,7 @@ libxfs_ialloc(
 	ASSERT(ip->i_d.di_nlink == nlink);
 	ip->i_d.di_uid = cr->cr_uid;
 	ip->i_d.di_gid = cr->cr_gid;
-	ip->i_d.di_projid = pip ? 0 : fsx->fsx_projid;
+	xfs_set_projid(&ip->i_d, pip ? 0 : fsx->fsx_projid);
 	memset(&(ip->i_d.di_pad[0]), 0, sizeof(ip->i_d.di_pad));
 
 	/*
@@ -167,10 +228,13 @@ libxfs_ialloc(
 	 * the inode version number now.  This way we only do the conversion
 	 * here rather than here and in the flush/logging code.
 	 */
-	if (XFS_SB_VERSION_HASNLINK(&tp->t_mountp->m_sb) &&
+	if (xfs_sb_version_hasnlink(&tp->t_mountp->m_sb) &&
 	    ip->i_d.di_version == XFS_DINODE_VERSION_1) {
 		ip->i_d.di_version = XFS_DINODE_VERSION_2;
-		/* old link count, projid field, pad field already zeroed */
+		/*
+		 * old link count, projid_lo/hi field, pad field
+		 * already zeroed
+		 */
 	}
 
 	if (pip && (pip->i_d.di_mode & S_ISGID)) {
@@ -182,7 +246,7 @@ libxfs_ialloc(
 	ip->i_d.di_size = 0;
 	ip->i_d.di_nextents = 0;
 	ASSERT(ip->i_d.di_nblocks == 0);
-	xfs_ichgtime(ip, XFS_ICHGTIME_CHG|XFS_ICHGTIME_ACC|XFS_ICHGTIME_MOD);
+	xfs_ichgtime(ip, XFS_ICHGTIME_CHG|XFS_ICHGTIME_MOD);
 	/*
 	 * di_gen will have been taken care of in xfs_iread.
 	 */
@@ -250,10 +314,11 @@ libxfs_ialloc(
 }
 
 void
-libxfs_iprint(xfs_inode_t	*ip)
+libxfs_iprint(
+	xfs_inode_t		*ip)
 {
-	xfs_dinode_core_t	*dip;
-	xfs_bmbt_rec_t		*ep;
+	xfs_icdinode_t		*dip;
+	xfs_bmbt_rec_host_t	*ep;
 	xfs_extnum_t		i;
 	xfs_extnum_t		nextents;
 
@@ -268,7 +333,8 @@ libxfs_iprint(xfs_inode_t	*ip)
 		(unsigned long)ip->i_df.if_u1.if_extents);
 	if (ip->i_df.if_flags & XFS_IFEXTENTS) {
 		nextents = ip->i_df.if_bytes / (uint)sizeof(*ep);
-		for (ep = ip->i_df.if_u1.if_extents, i = 0; i < nextents; i++, ep++) {
+		for (ep = ip->i_df.if_u1.if_extents, i = 0; i < nextents; 
+								i++, ep++) {
 			xfs_bmbt_irec_t rec;
 
 			xfs_bmbt_get_all(ep, &rec);
@@ -283,7 +349,7 @@ libxfs_iprint(xfs_inode_t	*ip)
 	printf("    i_df.if_broot %lx\n", (unsigned long)ip->i_df.if_broot);
 	printf("    i_df.if_broot_bytes %x\n", ip->i_df.if_broot_bytes);
 
-	dip = &(ip->i_d);
+	dip = &ip->i_d;
 	printf("\nOn disk portion\n");
 	printf("    di_magic %x\n", dip->di_magic);
 	printf("    di_mode %o\n", dip->di_mode);
@@ -334,7 +400,6 @@ libxfs_iflush_int(xfs_inode_t *ip, xfs_buf_t *bp)
 	/* set *dip = inode's place in the buffer */
 	dip = (xfs_dinode_t *)xfs_buf_offset(bp, ip->i_boffset);
 
-#ifdef DEBUG
 	ASSERT(ip->i_d.di_magic == XFS_DINODE_MAGIC);
 	if ((ip->i_d.di_mode & S_IFMT) == S_IFREG) {
 		ASSERT( (ip->i_d.di_format == XFS_DINODE_FMT_EXTENTS) ||
@@ -347,7 +412,6 @@ libxfs_iflush_int(xfs_inode_t *ip, xfs_buf_t *bp)
 	}
 	ASSERT(ip->i_d.di_nextents+ip->i_d.di_anextents <= ip->i_d.di_nblocks);
 	ASSERT(ip->i_d.di_forkoff <= mp->m_sb.sb_inodesize);
-#endif
 
 	/*
 	 * Copy the dirty parts of the inode into the on-disk
@@ -355,7 +419,7 @@ libxfs_iflush_int(xfs_inode_t *ip, xfs_buf_t *bp)
 	 * because if the inode is dirty at all the core must
 	 * be.
 	 */
-	xfs_xlate_dinode_core((xfs_caddr_t)&(dip->di_core), &(ip->i_d), -1);
+	xfs_dinode_to_disk(&dip->di_core, &ip->i_d);
 
 	/*
 	 * If this is really an old format inode and the superblock version
@@ -364,15 +428,14 @@ libxfs_iflush_int(xfs_inode_t *ip, xfs_buf_t *bp)
 	 * has been updated, then make the conversion permanent.
 	 */
 	ASSERT(ip->i_d.di_version == XFS_DINODE_VERSION_1 ||
-		XFS_SB_VERSION_HASNLINK(&mp->m_sb));
+		xfs_sb_version_hasnlink(&mp->m_sb));
 	if (ip->i_d.di_version == XFS_DINODE_VERSION_1) {
-		if (!XFS_SB_VERSION_HASNLINK(&mp->m_sb)) {
+		if (!xfs_sb_version_hasnlink(&mp->m_sb)) {
 			/*
 			 * Convert it back.
 			 */
 			ASSERT(ip->i_d.di_nlink <= XFS_MAXLINK_1);
-			INT_SET(dip->di_core.di_onlink, ARCH_CONVERT,
-				ip->i_d.di_nlink);
+			dip->di_core.di_onlink = cpu_to_be16(ip->i_d.di_nlink);
 		} else {
 			/*
 			 * The superblock version has already been bumped,
@@ -380,185 +443,23 @@ libxfs_iflush_int(xfs_inode_t *ip, xfs_buf_t *bp)
 			 * format permanent.
 			 */
 			ip->i_d.di_version = XFS_DINODE_VERSION_2;
-			INT_SET(dip->di_core.di_version, ARCH_CONVERT,
-				XFS_DINODE_VERSION_2);
+			dip->di_core.di_version =  XFS_DINODE_VERSION_2;
 			ip->i_d.di_onlink = 0;
 			dip->di_core.di_onlink = 0;
 			memset(&(ip->i_d.di_pad[0]), 0, sizeof(ip->i_d.di_pad));
 			memset(&(dip->di_core.di_pad[0]), 0,
-				sizeof(dip->di_core.di_pad));
-			ASSERT(ip->i_d.di_projid == 0);
+			      sizeof(dip->di_core.di_pad));
+			ASSERT(xfs_get_projid(ip->i_d) == 0);
 		}
 	}
 
-	if (xfs_iflush_fork(ip, dip, iip, XFS_DATA_FORK, bp) == EFSCORRUPTED)
-		return EFSCORRUPTED;
-	if (XFS_IFORK_Q(ip)) {
-		/* The only error from xfs_iflush_fork is on the data fork. */
+	xfs_iflush_fork(ip, dip, iip, XFS_DATA_FORK, bp);
+	if (XFS_IFORK_Q(ip)) 
 		xfs_iflush_fork(ip, dip, iip, XFS_ATTR_FORK, bp);
-	}
 
 	return 0;
 }
 
-/*
- * Given a block number in a fork, return the next valid block number
- * (not a hole).
- * If this is the last block number then NULLFILEOFF is returned.
- *
- * This was originally in the kernel, but only used in xfs_repair.
- */
-int
-libxfs_bmap_next_offset(
-	xfs_trans_t	*tp,			/* transaction pointer */
-	xfs_inode_t	*ip,			/* incore inode */
-	xfs_fileoff_t	*bnop,			/* current block */
-	int		whichfork)		/* data or attr fork */
-{
-	xfs_fileoff_t	bno;			/* current block */
-	int		eof;			/* hit end of file */
-	int		error;			/* error return value */
-	xfs_bmbt_irec_t got;			/* current extent value */
-	xfs_ifork_t	*ifp;			/* inode fork pointer */
-	xfs_extnum_t	lastx;			/* last extent used */
-	xfs_bmbt_irec_t prev;			/* previous extent value */
-
-	if (XFS_IFORK_FORMAT(ip, whichfork) != XFS_DINODE_FMT_BTREE &&
-	    XFS_IFORK_FORMAT(ip, whichfork) != XFS_DINODE_FMT_EXTENTS &&
-	    XFS_IFORK_FORMAT(ip, whichfork) != XFS_DINODE_FMT_LOCAL)
-	       return XFS_ERROR(EIO);
-	if (XFS_IFORK_FORMAT(ip, whichfork) == XFS_DINODE_FMT_LOCAL) {
-		*bnop = NULLFILEOFF;
-		return 0;
-	}
-	ifp = XFS_IFORK_PTR(ip, whichfork);
-	if (!(ifp->if_flags & XFS_IFEXTENTS) &&
-	    (error = xfs_iread_extents(tp, ip, whichfork)))
-		return error;
-	bno = *bnop + 1;
-	xfs_bmap_search_extents(ip, bno, whichfork, &eof, &lastx, &got, &prev);
-	if (eof)
-		*bnop = NULLFILEOFF;
-	else
-		*bnop = got.br_startoff < bno ? bno : got.br_startoff;
-	return 0;
-}
-
-/*
- * Like xfs_dir_removename, but only for removing entries with
- * (name, hashvalue) pairs that may not be consistent (hashvalue
- * may not be correctly set for the name).
- *
- * This was originally in the kernel, but only used in xfs_repair.
- */
-int
-xfs_dir_bogus_removename(xfs_trans_t *trans, xfs_inode_t *dp, uchar_t *name,
-		xfs_fsblock_t *firstblock, xfs_bmap_free_t *flist,
-		xfs_extlen_t total, xfs_dahash_t hashval, int namelen)
-{
-	xfs_da_args_t args;
-	int count, totallen, newsize, retval;
-
-	ASSERT((dp->i_d.di_mode & S_IFMT) == S_IFDIR);
-	if (namelen >= MAXNAMELEN) {
-		return EINVAL;
-	}
-
-	/*
-	 * Fill in the arg structure for this request.
-	 */
-	args.name = name;
-	args.namelen = namelen;
-	args.hashval = hashval;
-	args.inumber = 0;
-	args.dp = dp;
-	args.firstblock = firstblock;
-	args.flist = flist;
-	args.total = total;
-	args.whichfork = XFS_DATA_FORK;
-	args.trans = trans;
-	args.justcheck = args.addname = 0;
-	args.oknoent = 1;
-
-	/*
-	 * Decide on what work routines to call based on the inode size.
-	 */
-	if (dp->i_d.di_format == XFS_DINODE_FMT_LOCAL) {
-		retval = xfs_dir_shortform_removename(&args);
-	} else if (xfs_bmap_one_block(dp, XFS_DATA_FORK)) {
-		retval = xfs_dir_leaf_removename(&args, &count, &totallen);
-		if (retval == 0) {
-			newsize = XFS_DIR_SF_ALLFIT(count, totallen);
-			if (newsize <= XFS_IFORK_DSIZE(dp)) {
-				retval = xfs_dir_leaf_to_shortform(&args);
-			}
-		}
-	} else {
-		retval = xfs_dir_node_removename(&args);
-	}
-	return(retval);
-}
-
-/*
- * Like xfs_dir_removename, but only for removing entries with
- * (name, hashvalue) pairs that may not be consistent (hashvalue
- * may not be correctly set for the name).
- *
- * This was originally in the kernel, but only used in xfs_repair.
- */
-int
-xfs_dir2_bogus_removename(
-	xfs_trans_t	*tp,		/* transaction pointer */
-	xfs_inode_t	*dp,		/* incore directory inode */
-	uchar_t		*name,		/* name of entry to remove */
-	xfs_fsblock_t	*first,		/* bmap's firstblock */
-	xfs_bmap_free_t *flist,		/* bmap's freeblock list */
-	xfs_extlen_t	total,		/* bmap's total block count */
-	xfs_dahash_t	hash,		/* name's real hash value */
-	int		namelen)	/* entry's name length */
-{
-	xfs_da_args_t	args;		/* operation arguments */
-	int		rval;		/* return value */
-	int		v;		/* type-checking value */
-
-	ASSERT((dp->i_d.di_mode & S_IFMT) == S_IFDIR);
-	if (namelen >= MAXNAMELEN)
-		return EINVAL;
-
-	/*
-	 * Fill in the arg structure for this request.
-	 */
-	args.name = name;
-	args.namelen = namelen;
-	args.hashval = hash;
-	args.inumber = 0;
-	args.dp = dp;
-	args.firstblock = first;
-	args.flist = flist;
-	args.total = total;
-	args.whichfork = XFS_DATA_FORK;
-	args.trans = tp;
-	args.justcheck = args.addname = 0;
-	args.oknoent = 1;
-
-	/*
-	 * Decide on what work routines to call based on the inode size.
-	 */
-	if (dp->i_d.di_format == XFS_DINODE_FMT_LOCAL)
-		rval = xfs_dir2_sf_removename(&args);
-	else if ((rval = xfs_dir2_isblock(tp, dp, &v)))
-		return rval;
-	else if (v)
-		rval = xfs_dir2_block_removename(&args);
-	else if ((rval = xfs_dir2_isleaf(tp, dp, &v)))
-		return rval;
-	else if (v)
-		rval = xfs_dir2_leaf_removename(&args);
-	else
-		rval = xfs_dir2_node_removename(&args);
-	return rval;
-}
-
 /*
  * Utility routine common used to apply a delta to a field in the
  * in-core superblock.
@@ -566,10 +467,14 @@ xfs_dir2_bogus_removename(
  * Fields are not allowed to dip below zero, so if the delta would
  * do this do not apply it and return EINVAL.
  *
- * Originally derived from xfs_mod_incore_sb().
+ * Originally derived from xfs_mod_incore_sb_unlocked().
  */
 int
-libxfs_mod_incore_sb(xfs_mount_t *mp, xfs_sb_field_t field, int delta, int rsvd)
+libxfs_mod_incore_sb(
+	xfs_mount_t	*mp,
+	xfs_sb_field_t	field,
+	int64_t		delta,
+	int		rsvd)
 {
 	long long	lcounter;	/* long counter for 64 bit fields */
 
@@ -578,20 +483,19 @@ libxfs_mod_incore_sb(xfs_mount_t *mp, xfs_sb_field_t field, int delta, int rsvd)
 		lcounter = (long long)mp->m_sb.sb_fdblocks;
 		lcounter += delta;
 		if (lcounter < 0)
-			return (XFS_ERROR(ENOSPC));
+			return XFS_ERROR(ENOSPC);
 		mp->m_sb.sb_fdblocks = lcounter;
-		break;
+		return 0;
 	default:
 		ASSERT(0);
+		return XFS_ERROR(EINVAL);
 	}
-	return 0;
 }
 
 int
 libxfs_bmap_finish(
 	xfs_trans_t	**tp,
 	xfs_bmap_free_t *flist,
-	xfs_fsblock_t	firstblock,
 	int		*committed)
 {
 	xfs_bmap_free_item_t	*free;	/* free extent list item */
@@ -670,16 +574,16 @@ libxfs_alloc_file_space(
 		XFS_BMAP_INIT(&free_list, &firstfsb);
 		error = xfs_bmapi(tp, ip, startoffset_fsb, allocatesize_fsb,
 				xfs_bmapi_flags, &firstfsb, 0, imapp,
-				&reccount, &free_list);
+				&reccount, &free_list, NULL);
 		if (error)
 			break;
 
 		/* complete the transaction */
-		error = xfs_bmap_finish(&tp, &free_list, firstfsb, &committed);
+		error = xfs_bmap_finish(&tp, &free_list, &committed);
 		if (error)
 			break;
 
-		error = xfs_trans_commit(tp, 0, NULL);
+		error = xfs_trans_commit(tp, 0);
 		if (error)
 			break;
 
@@ -721,7 +625,7 @@ libxfs_da_read_bufr(
 	xfs_dabuf_t	**bpp,
 	int		whichfork)
 {
-	return libxfs_da_do_buf(trans, dp, bno, &mappedbno, bpp, whichfork, 2,
+	return xfs_da_do_buf(trans, dp, bno, &mappedbno, bpp, whichfork, 2,
 		(inst_t *)__return_address);
 }
 
@@ -790,7 +694,7 @@ libxfs_inode_alloc(
 	if (call_again) {
 		xfs_trans_bhold(*tp, ialloc_context);
 		ntp = xfs_trans_dup(*tp);
-		xfs_trans_commit(*tp, 0, NULL);
+		xfs_trans_commit(*tp, 0);
 		*tp = ntp;
 		if ((i = xfs_trans_reserve(*tp, 0, 0, 0, 0, 0))) {
 			fprintf(stderr, _("%s: cannot reserve space: %s\n"),
@@ -817,7 +721,7 @@ libxfs_inode_alloc(
  * Userspace versions of common diagnostic routines (varargs fun).
  */
 void
-xfs_fs_repair_cmn_err(int level, xfs_mount_t *mp, char *fmt, ...)
+libxfs_fs_repair_cmn_err(int level, xfs_mount_t *mp, char *fmt, ...)
 {
 	va_list	ap;
 
@@ -830,7 +734,7 @@ xfs_fs_repair_cmn_err(int level, xfs_mount_t *mp, char *fmt, ...)
 }
 
 void
-xfs_fs_cmn_err(int level, xfs_mount_t *mp, char *fmt, ...)
+libxfs_fs_cmn_err(int level, xfs_mount_t *mp, char *fmt, ...)
 {
 	va_list	ap;
 
